<?php

$versions = array(
    '1.0.1',
    '1.1.0.beta1',
    '1.1.0.RC1',
    '1.1.0.RC2',
    '1.1.0',
    '1.1.1',
    '1.2.0.RC1',
    '1.2.0.RC2',
    '1.2.1',
);
